<?php

namespace Litecms\Accountblacklist\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Accountblacklist\Models\Accountblacklist;

class AccountblacklistPolicy
{

    /**
     * Determine if the given user can view the accountblacklist.
     *
     * @param UserPolicy $user
     * @param Accountblacklist $accountblacklist
     *
     * @return bool
     */
    public function view(UserPolicy $user, Accountblacklist $accountblacklist)
    {
        if ($user->canDo('accountblacklist.accountblacklist.view') && $user->isAdmin()) {
            return true;
        }

        return $accountblacklist->user_id == user_id() && $accountblacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a accountblacklist.
     *
     * @param UserPolicy $user
     * @param Accountblacklist $accountblacklist
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('accountblacklist.accountblacklist.create');
    }

    /**
     * Determine if the given user can update the given accountblacklist.
     *
     * @param UserPolicy $user
     * @param Accountblacklist $accountblacklist
     *
     * @return bool
     */
    public function update(UserPolicy $user, Accountblacklist $accountblacklist)
    {
        if ($user->canDo('accountblacklist.accountblacklist.edit') && $user->isAdmin()) {
            return true;
        }

        return $accountblacklist->user_id == user_id() && $accountblacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given accountblacklist.
     *
     * @param UserPolicy $user
     * @param Accountblacklist $accountblacklist
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Accountblacklist $accountblacklist)
    {
        return $accountblacklist->user_id == user_id() && $accountblacklist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given accountblacklist.
     *
     * @param UserPolicy $user
     * @param Accountblacklist $accountblacklist
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Accountblacklist $accountblacklist)
    {
        if ($user->canDo('accountblacklist.accountblacklist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given accountblacklist.
     *
     * @param UserPolicy $user
     * @param Accountblacklist $accountblacklist
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Accountblacklist $accountblacklist)
    {
        if ($user->canDo('accountblacklist.accountblacklist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
